[Libreoffice-commits] .: qadevOOo/tests sc/qa

Markus Mohrhard mmohrhard at kemper.freedesktop.org
Wed Jan 25 16:38:16 PST 2012


 dev/null                                       |binary
 qadevOOo/tests/java/mod/_sc/ScDDELinkObj.java  |    6 +++---
 qadevOOo/tests/java/mod/_sc/ScDDELinksObj.java |    6 +++---
 sc/qa/unoapi/sc.sce                            |    4 ++--
 sc/qa/unoapi/testdocuments/ScDDELinksObj.ods   |binary
 5 files changed, 8 insertions(+), 8 deletions(-)

New commits:
commit 80eecd4677c5a1b61be1a34eea4bbecdc7e95e80
Author: Markus Mohrhard <markus.mohrhard at googlemail.com>
Date:   Thu Jan 26 01:32:32 2012 +0100

    switch subsequenttest testdocs from sdc to ods, fdo#43376

diff --git a/sc/qa/unoapi/sc.sce b/sc/qa/unoapi/sc.sce
index dabb97a..1a38b3a 100644
--- a/sc/qa/unoapi/sc.sce
+++ b/sc/qa/unoapi/sc.sce
@@ -37,8 +37,8 @@
 -o sc.ScChartObj
 -o sc.ScChartsObj
 -o sc.ScConsolidationDescriptor
-# fdo43376 -o sc.ScDDELinkObj
-# fdo43376 -o sc.ScDDELinksObj
+-o sc.ScDDELinkObj
+-o sc.ScDDELinksObj
 -o sc.ScDataPilotFieldGroupItemObj
 -o sc.ScDataPilotFieldGroupObj
 -o sc.ScDataPilotFieldGroupsObj
diff --git a/qadevOOo/tests/java/mod/_sc/ScDDELinkObj.java b/qadevOOo/tests/java/mod/_sc/ScDDELinkObj.java
index a1f3dfb..fe67abc 100644
--- a/qadevOOo/tests/java/mod/_sc/ScDDELinkObj.java
+++ b/qadevOOo/tests/java/mod/_sc/ScDDELinkObj.java
@@ -58,7 +58,7 @@ import com.sun.star.uno.XInterface;
 * </ul>
 * The following files used by this test :
 * <ul>
 *  <li><b> ScDDELinksObj.sdc </b> : the predefined testdocument </li>
 * </ul> <p>
 * @see com.sun.star.sheet.DDELink
 * @see com.sun.star.container.XNamed
@@ -145,7 +145,7 @@ public class ScDDELinkObj extends TestCase {
         XMultiServiceFactory oMSF = (XMultiServiceFactory)Param.getMSF();
 
         // load the predefined testdocument
-        String testdoc = util.utils.getFullTestURL("ScDDELinksObj.sdc");
+        String testdoc = util.utils.getFullTestURL("ScDDELinksObj.ods");
         try {
             oDoc = SOfficeFactory.getFactory(oMSF).loadDocument(testdoc);
         } catch (com.sun.star.lang.IllegalArgumentException e) {
@@ -183,7 +183,7 @@ public class ScDDELinkObj extends TestCase {
         log.println("filling some cells");
         String sAppl = "soffice";
         String sItem = "Sheet1.A1";
-        testdoc = util.utils.getFullTestDocName("ScDDELinksObj.sdc");
+        testdoc = util.utils.getFullTestDocName("ScDDELinksObj.ods");
         try {
             oSheet.getCellByPosition(5, 5).setFormula(
                 "=DDE(\""+ sAppl +"\";\""+testdoc+"\";\""+ sItem +"\"");
@@ -58,7 +58,7 @@ import com.sun.star.uno.XInterface;
 * The following files used by this test :
 * <ul>
-*  <li><b> ScDDELinksObj.sdc </b> : the predefined testdocument </li>
+*  <li><b> ScDDELinksObj.ods </b> : the predefined testdocument </li>
 * </ul> <p>
 * @see com.sun.star.sheet.DDELink
diff --git a/qadevOOo/tests/java/mod/_sc/ScDDELinksObj.java b/qadevOOo/tests/java/mod/_sc/ScDDELinksObj.java
index fbcb724..d37579c 100644
--- a/qadevOOo/tests/java/mod/_sc/ScDDELinksObj.java
+++ b/qadevOOo/tests/java/mod/_sc/ScDDELinksObj.java
@@ -58,7 +58,7 @@ import com.sun.star.uno.XInterface;
 * </ul>
 * The following files used by this test :
 * <ul>
 *  <li><b> ScDDELinksObj.sdc </b> : the predefined testdocument </li>
 * </ul> <p>
 * @see com.sun.star.sheet.DDELinks
 * @see com.sun.star.container.XNameAccess
@@ -124,7 +124,7 @@ public class ScDDELinksObj extends TestCase {
         XMultiServiceFactory oMSF = (XMultiServiceFactory)Param.getMSF();
 
         // load the predefined testdocument
-        String testdoc = utils.getFullTestURL("ScDDELinksObj.sdc");
+        String testdoc = utils.getFullTestURL("ScDDELinksObj.ods");
         try {
             oDoc = SOfficeFactory.getFactory(oMSF).loadDocument(testdoc);
         } catch (com.sun.star.lang.IllegalArgumentException e) {
@@ -159,7 +159,7 @@ public class ScDDELinksObj extends TestCase {
             throw new StatusException("Couldn't get a spreadsheet", e);
         }
 
-        testdoc = utils.getFullTestDocName("ScDDELinksObj.sdc");
+        testdoc = utils.getFullTestDocName("ScDDELinksObj.ods");
         log.println("filling some cells");
         try {
             oSheet.getCellByPosition(5, 5).setFormula(
@@ -58,7 +58,7 @@ import com.sun.star.uno.XInterface;
 * The following files used by this test :
 * <ul>
-*  <li><b> ScDDELinksObj.sdc </b> : the predefined testdocument </li>
+*  <li><b> ScDDELinksObj.ods </b> : the predefined testdocument </li>
 * </ul> <p>
 * @see com.sun.star.sheet.DDELinks
diff --git a/sc/qa/unoapi/testdocuments/ScDDELinksObj.ods b/sc/qa/unoapi/testdocuments/ScDDELinksObj.ods
new file mode 100644
index 0000000..01c11e3
Binary files /dev/null and b/sc/qa/unoapi/testdocuments/ScDDELinksObj.ods differ
diff --git a/sc/qa/unoapi/testdocuments/ScDDELinksObj.sdc b/sc/qa/unoapi/testdocuments/ScDDELinksObj.sdc
deleted file mode 100644
index 1abdbf4..0000000
Binary files a/sc/qa/unoapi/testdocuments/ScDDELinksObj.sdc and /dev/null differ


More information about the Libreoffice-commits mailing list